@@ -27,3 +27,7 @@ class RPDWarning(Warning):
 
 class Deprecated(RPDWarning):
     """Gets raised when a object has been deprecated but not removed"""
+
+
+class NaClWarning(RPDWarning):
+    """Raised when you don't have PyNaCl"""
