@@ -23,19 +23,28 @@
 
 import time
 
-from rpd.api.gateway import Gateway
-
 
 class Presence:
-    def __init__(self, state, status: str = "online", afk: bool = False):
+    def __init__(self, state, gateway, status: str = "online", afk: bool = False):
         self.state = state
-        self.gate = Gateway(state=self.state)
+        self.gate = gateway
         self.status = status
         self.afk = afk
 
     async def add(self, name: str, type: int = 0):
-        if not self.gate.ws:
-            raise
+        await self.gate.send(
+            {
+                "op": 3,
+                "d": {
+                    "since": time.time() if self.afk is True else None,
+                    "activites": [{"name": str(name), "type": int(type)}],
+                    "status": self.status,
+                    "afk": self.afk,
+                },
+            }
+        )
+
+    async def edit(self, name, type: int = 0):
         await self.gate.send(
             {
                 "op": 3,
@@ -47,18 +56,3 @@ class Presence:
                 },
             }
         )
-
-    async def edit(self, name, type: int = 0):
-        if not self.gate.ws:
-            raise
-        self.gate.send(
-            {
-                "op": 3,
-                "d": {
-                    "since": time.time(),
-                    "activites": [{"name": str(name), "type": int(type)}],
-                    "status": self.status,
-                    "afk": self.afk,
-                },
-            }
-        )
