@@ -19,8 +19,13 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE
-# Snowflake implementation
-from typing import List, Union
+"""Snowflake implementation"""
+from typing import TypeVar, Union
 
-Snowflake = Union[str, int]
-SnowflakeList = List[Snowflake]
+T = TypeVar("T", covariant=True)
+
+Snowflakeish = int
+
+SnowflakeishList = list[Snowflakeish]
+
+SnowflakeishOr = Union[T, Snowflakeish]
